@@ -150,15 +150,17 @@ void ReusableAllocator::release(ReusableObject *obj)
 {
 	assert(obj != NULL);
 
-	LinkedObject **ru = (LinkedObject **)freelist;
+	LinkedObject **ru = (LinkedObject **)&freelist;
 
 	obj->retain();
 	obj->release();
 
 	lock();
 	obj->enlist(ru);
+
 	if(waiting)
 		signal();
+
 	unlock();
 }
 
