@@ -225,6 +225,14 @@ public:
 	 */
 	int stat(struct stat *buffer);
 
+	/**
+	 * Truncate file to specified length.  The file pointer is positioned
+	 * to the new end of file.
+	 * @param offset to truncate to.
+	 * @return true if truncate successful.
+	 */
+	int trunc(offset_t offset);
+
 	/**
 	 * Commit changes to the filesystem.
 	 * @return error number or 0 on success.
@@ -442,7 +450,7 @@ public:
 	 */
 	static void *find(fsys& module, const char *symbol);
 };
-
+	
 /**
  * Convience type for fsys.
  */
