@@ -20,8 +20,6 @@
  * @file ucommon/shell.h
  */
 
-#if defined(OLD_STDCPP) || defined(NEW_STDCPP)
-
 #ifndef	_UCOMMON_STRING_H_
 #include <ucommon/string.h>
 #endif
@@ -118,7 +116,7 @@ public:
 	protected:
 		/**
 		 * Used to send option into derived receiver.
-		 * @param option that was received.
+		 * @param value option that was received.
 		 * @return NULL or error string to use.
 		 */
 		virtual const char *assign(const char *value) = 0;
@@ -220,5 +218,3 @@ public:
 END_NAMESPACE
 
 #endif
-
-#endif
